/**
 * @file
 * Attaches behavior for the Filter Tooltips module.
 */

(function ($, Drupal) {
  'use strict';

  /**
   * Displays the tooltips of the selected text format automatically.
   *
   * @type {Drupal~behavior}
   *
   * @prop {Drupal~behaviorAttach} attach
   *   Attaches behavior for updating filter tooltips.
   */
  Drupal.behaviors.filterTooltips = {
    attach: function attach(context, settings) {
      $('.filter-tooltips', context).on(settings.filter_tooltips.trigger_event, function (event) {
        event.preventDefault();
        if (!$(this).next().hasClass('filter-tooltips-explanation')) {
          var div = jQuery('<div/>', {
            class: 'filter-tooltips-explanation',
            html: $(this).data('explanation')
          });
          $(this).after(div);
        }

        var explanation = $(this).next();
        if (explanation.hasClass('open')) {
          explanation.slideToggle(function () {
            explanation.remove();
          });
          $(this).attr('aria-expanded', 'false');
        }
        else {
          explanation.hide().addClass('open').slideToggle();
          $(this).attr('aria-expanded', 'true');
        }
      });

      if (settings.filter_tooltips.trigger_event == 'mouseover') {
        $('.filter-tooltips', context).on('mouseout', function (event) {
          var explanation = $(this).next();
          if (explanation.hasClass('open')) {
            explanation.slideToggle(function () {
              explanation.remove();
            });
            $(this).attr('aria-expanded', 'false');
          }
        });
      }
    }
  };
})(jQuery, Drupal);
